aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSebastian Pop <sebastian.pop@amd.com>2010-04-07 06:33:55 +0000
committerSebastian Pop <spop@gcc.gnu.org>2010-04-07 06:33:55 +0000
commit62ef243189943eeec4e8e51c0252006589a486e5 (patch)
tree66ada3bcd0734431a3b7efbb5409dd5788355485
parentbaaa8e9638e4f5681fa80840b4cae44122b7e6b7 (diff)
downloadgcc-62ef243189943eeec4e8e51c0252006589a486e5.zip
gcc-62ef243189943eeec4e8e51c0252006589a486e5.tar.gz
gcc-62ef243189943eeec4e8e51c0252006589a486e5.tar.bz2
Fix comments.
2010-04-07 Sebastian Pop <sebastian.pop@amd.com> * tree-if-conv.c: Fix indentation and comments. From-SVN: r158041
-rw-r--r--gcc/ChangeLog4
-rw-r--r--gcc/tree-if-conv.c25
2 files changed, 17 insertions, 12 deletions
diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 32a4bed..4eae15a 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,5 +1,9 @@
2010-04-07 Sebastian Pop <sebastian.pop@amd.com>
+ * tree-if-conv.c: Fix indentation and comments.
+
+2010-04-07 Sebastian Pop <sebastian.pop@amd.com>
+
* tree-if-conv.c: Sort static functions in topological order.
2010-04-07 Sebastian Pop <sebastian.pop@amd.com>
diff --git a/gcc/tree-if-conv.c b/gcc/tree-if-conv.c
index 3b2386a..4a563f3 100644
--- a/gcc/tree-if-conv.c
+++ b/gcc/tree-if-conv.c
@@ -130,7 +130,7 @@ ifc_temp_var (tree type, tree exp)
return stmt;
}
-/* Add condition COND into predicate list of basic block BB. */
+/* Add condition NEW_COND into predicate list of basic block BB. */
static void
add_to_predicate_list (basic_block bb, tree new_cond)
@@ -139,16 +139,18 @@ add_to_predicate_list (basic_block bb, tree new_cond)
if (cond)
cond = fold_build2_loc (EXPR_LOCATION (cond),
- TRUTH_OR_EXPR, boolean_type_node,
- unshare_expr (cond), new_cond);
+ TRUTH_OR_EXPR, boolean_type_node,
+ unshare_expr (cond), new_cond);
else
cond = new_cond;
bb->aux = cond;
}
-/* Add condition COND into BB's predicate list. PREV_COND is
- existing condition. */
+/* And condition COND to the previous condition PREV_COND and add this
+ to the predicate list of the destination of edge E. GSI is the
+ place where the gimplification of the resulting condition should
+ output code. LOOP is the loop to be if-converted. */
static tree
add_to_dst_predicate_list (struct loop *loop, edge e,
@@ -254,7 +256,7 @@ tree_if_convert_cond_stmt (struct loop *loop, gimple stmt, tree cond,
loop. It is used here when it is required to delete current statement. */
static tree
-tree_if_convert_stmt (struct loop * loop, gimple t, tree cond,
+tree_if_convert_stmt (struct loop *loop, gimple t, tree cond,
gimple_stmt_iterator *gsi)
{
if (dump_file && (dump_flags & TDF_DETAILS))
@@ -872,8 +874,8 @@ replace_phi_with_cond_gimple_assign_stmt (gimple phi, tree cond,
}
}
-/* Process phi nodes for the given LOOP. Replace phi nodes with cond
- modify expr. */
+/* Process phi nodes for the given LOOP. Replace phi nodes with
+ conditional modify expressions. */
static void
process_phi_nodes (struct loop *loop)
@@ -882,7 +884,6 @@ process_phi_nodes (struct loop *loop)
unsigned int orig_loop_num_nodes = loop->num_nodes;
unsigned int i;
- /* Replace phi nodes with cond. modify expr. */
for (i = 1; i < orig_loop_num_nodes; i++)
{
gimple phi;
@@ -897,7 +898,7 @@ process_phi_nodes (struct loop *loop)
phi_gsi = gsi_start_phis (bb);
gsi = gsi_after_labels (bb);
- /* BB has two predecessors. Using predecessor's aux field, set
+ /* BB has two predecessors. Using predecessor's aux field, set
appropriate condition for the PHI node replacement. */
if (!gsi_end_p (phi_gsi))
true_bb = find_phi_replacement_condition (loop, bb, &cond, &gsi);
@@ -914,8 +915,8 @@ process_phi_nodes (struct loop *loop)
return;
}
-/* Combine all basic block from the given LOOP into one or two super
- basic block. Replace PHI nodes with conditional modify expression. */
+/* Combine all the basic blocks from LOOP into one or two super basic
+ blocks. Replace PHI nodes with conditional modify expressions. */
static void
combine_blocks (struct loop *loop)